/* This file is part of the Amalthea library.
 *
 * Copyright (C) 2019-2020 Eugene 'Vindex' Stulin
 *
 * The Amalthea library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This libary is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

module amalthea.fileformats;

import
    std.algorithm,
    std.datetime,
    std.file,
    std.path,
    std.process,
    std.stdio,
    std.string,
    std.utf;


/*******************************************************************************
 * File format info.
 */
struct FileFormat {
    /// Key byte sequence.
    ubyte[] signature;
    /// Offset of the signature from the beginning of the file.
    uint offset;
    /// Format name.
    string format;
    /// Format brief description.
    string description;
    /// List of file suffixes used by the format.
    string[] extensions;
    /// Format group name (Audio, Pictures, Archives, etc.).
    string group;
}


/*******************************************************************************
 * The function gets the FileFormat structure with info about file format.
 */
FileFormat getFileFormat(string filepath) {
    if (!filepath.exists || !filepath.isFile) {
        throw new FileException("Access error");
    }
    return signatureSearch(filepath);
}


/*******************************************************************************
 * The function returns true if specified file contains plain Unicode-text.
 */
bool isUnicodeTextFile(string filepath) nothrow {
    try {
        File(filepath, "r").byLine.each!validate;
    } catch (Exception e) {
        return false;
    }
    return true;
}


private FileFormat signatureSearch(string filepath) {
    static FileFormat[] searchByExtensions(in FileFormat[] candidates,
                                           string fpath) {
        fpath = fpath.toLower;
        FileFormat[] newCandidates;
        FileFormat[] newCandidatesWithExtensions;
        FileFormat[] newCandidatesWithoutExtensions;
        foreach(ftype; candidates) {
            foreach(ext; ftype.extensions) {
                auto end = "." ~ ext;
                if (ext == "*") {
                    newCandidatesWithoutExtensions ~= cast(FileFormat)ftype;
                } else if (fpath.endsWith(end) || fpath.canFind(end ~ ".")) {
                    newCandidatesWithExtensions ~= cast(FileFormat)ftype;
                }
            }
        }
        if (newCandidatesWithExtensions.length == 0) {
            newCandidates = newCandidatesWithoutExtensions;
        } else {
            newCandidates = newCandidatesWithExtensions;
        }
        return newCandidates;
    }
    static FileFormat[] searchBySignature(in FileFormat[] candidates,
                                          in ubyte[] data) {
        FileFormat[] newCandidates;
        foreach(ftype; candidates) {
            auto offset = ftype.offset;
            auto signature = ftype.signature;
            if (signature.length + offset > data.length) {
                continue;
            }
            if (ftype.signature == data[offset .. offset + signature.length]) {
                newCandidates ~= cast(FileFormat)ftype;
            }
        }
        return newCandidates;
    }
    static FileFormat identifyLikelySignature(in FileFormat[] candidates,
                                              ubyte[] data,
                                              string fpath)
    in {
        assert(candidates.length > 1);
    }
    body {
        FileFormat result = cast(FileFormat)candidates[0];
        size_t maxNumberOfBytes = result.signature.length;
        foreach(ftype; candidates[1 .. $]) {
            if (ftype.signature.length > maxNumberOfBytes) {
                if (ftype.offset > result.offset) continue;
                maxNumberOfBytes = ftype.signature.length;
                result = cast(FileFormat)ftype;
            }
        }
        if (result == FileFormat.init) {
            return altFormatSearch(fpath);
        } else {
            return result;
        }
    }
    
    auto f = File(filepath, "r");
    ubyte[] buffer;
    buffer.length = 1024;
    ubyte[] data = f.rawRead(buffer);

    FileFormat[] candidates = searchByExtensions(fileformats, filepath);
    if (!candidates.empty) {
        //filter candidates
        candidates = searchBySignature(candidates, data);
    }
    if (candidates.empty) {
        // search among all formats
        auto signCandidates = searchBySignature(fileformats, data);
        auto ext = extension(filepath).stripLeft('.');
        foreach(c; signCandidates) {
            if (c.signature.empty) {
                if (c.extensions.canFind(ext)) {
                    candidates ~= c;
                }
            }
        }
    }
    
    if (candidates.empty) {
        return altFormatSearch(filepath);
    } else if (candidates.length == 1) {
        return candidates[0];
    } else { // a lot of candidates
        return identifyLikelySignature(candidates, data, filepath);
    }
}


private FileFormat altFormatSearch(string filepath) {
    string ext = std.path.extension(filepath).stripLeft('.');
    auto cmdArray = ["mimetype", "-L", "--output-format", "%m:%d", filepath];

    string result = execute(cmdArray).output;
    auto splitted = result.strip.split('\n');
    result = splitted[$-1];

    splitted = result.split(':');
    string mimetype = std.string.strip(splitted[0]);
    string mimegroup = mimetype.split('/')[0];
    string mimeformat = mimetype.split('/')[1];
    string description = std.string.strip(splitted[1]);

    FileFormat ff;
    ff.format = ext.empty ? mimeformat : ext.toUpper;
    ff.description = description.capitalize;
    if (ff.description == "Plain text document" && ff.format == "plain") {
        ff.format = "TXT";
    } else if (mimeformat.endsWith("src")) {
        ff.format = ff.description;
    }
    if (isUnicodeTextFile(filepath) || mimegroup == "text") {
        ff.group = "Text";
    }
    return ff;
}


//list is generated from csv-table (`make update_fileformats`)
private static const FileFormat[] fileformats = 
[
FileFormat([0x00], 0, "PIC", "IBM Storyboard bitmap file", ["pic"], "Pictures"),
FileFormat([0x00], 0, "PIF", "Windows Program Information File", ["pif"], ""),
FileFormat([0x00], 0, "SEA", "Mac Stuffit Self-Extracting Archive", ["sea"], ""),
FileFormat([0x00], 0, "YTR", "IRIS OCR data file", ["ytr"], ""),
FileFormat([0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00], 11, "PDB", "PalmPilot Database/Document File", ["pdb"], ""),
FileFormat([0x00,0x00,0x00,0x0C,0x6A,0x50,0x20,0x20], 0, "JPEG2000", "JPEG-2000 image", ["jp2"], "Pictures"),
FileFormat([0x00,0x00,0x01,0x00], 0, "ICO", "Windows icon file", ["ico"], "Pictures"),
FileFormat([0x00,0x00,0x01,0x00], 0, "SPL", "Windows printer spool file", ["spl"], ""),
FileFormat([0x00,0x00,0x01], 0, "MPEG", "MPEG video file", ["mpg", "m2p", "mpeg"], "Video"),
FileFormat([0x00,0x00,0x01], 0, "VOB", "DVD video file", ["vob"], "Video"),
FileFormat([0x00,0x00,0x02,0x00], 0, "WB2", "QuattroPro spreadsheet", ["wb2"], ""),
FileFormat([0x00,0x00,0x02,0x00], 0, "CUR", "Windows cursor", ["cur"], ""),
FileFormat([0x00,0x00,0x02,0x00,0x06,0x04,0x06,0x00,0x08], 0, "WK1", "Lotus 1-2-3 (v.1)", ["wk1"], ""),
FileFormat([0x00,0x00,0x1A,0x00,0x00,0x10,0x04], 0, "WK3", "Lotus 1-2-3 (v.3)", ["wk3"], ""),
FileFormat([0x00,0x00,0x1A,0x00,0x02,0x10,0x04], 0, "WK4", "Lotus 1-2-3 (v.4)", ["wk4"], ""),
FileFormat([0x00,0x00,0x1A,0x00,0x02,0x10,0x04], 0, "WK5", "Lotus 1-2-3 (v.5)", ["wk5"], ""),
FileFormat([0x00,0x00,0x1A,0x00,0x05,0x10,0x04], 0, "123", "Lotus 1-2-3 (v.9)", ["123"], ""),
FileFormat([0x00,0x00,0x49,0x49,0x58,0x50,0x52], 0, "QXD", "Quark Express (Intel)", ["qxd"], ""),
FileFormat([0x00,0x00,0x4D,0x4D,0x58,0x50,0x52], 0, "QXD", "Quark Express (Motorola)", ["qxd"], ""),
FileFormat([0x00,0x00,0xFF,0xFF,0xFF,0xFF], 6, "HLP", "Windows Help", ["hlp"], ""),
FileFormat([0x00,0x01,0x00,0x00], 0, "Palm Desktop Data File", "Palm Desktop Data File (MS Access Format)", ["*"], ""),
FileFormat([0x00,0x01,0x00,0x00,0x4D,0x53,0x49,0x53,0x41,0x4D,0x20,0x44,0x61,0x74,0x61,0x62,0x61,0x73,0x65], 0, "MNY", "Microsoft Money file", ["mny"], ""),
FileFormat([0x00,0x01,0x00,0x00,0x53,0x74,0x61,0x6E,0x64,0x61,0x72,0x64,0x20,0x41,0x43,0x45,0x20,0x44,0x42], 0, "ACCDB", "Microsoft Access 2007 file", ["accdb"], ""),
FileFormat([0x00,0x01,0x00,0x00,0x53,0x74,0x61,0x6E,0x64,0x61,0x72,0x64,0x20,0x4A,0x65,0x74,0x20,0x44,0x42], 0, "MDB", "Microsoft Access file", ["mdb"], ""),
FileFormat([0x00,0x01,0x42,0x41], 0, "ABA", "Palm Address Book Archive", ["aba"], ""),
FileFormat([0x00,0x01,0x42,0x44], 0, "DBA", "Palm DateBook Archive", ["dba"], ""),
FileFormat([0x00,0x06,0x15,0x61,0x00,0x00,0x00,0x02,0x00,0x00,0x04,0xD2,0x00,0x00,0x10,0x00], 0, "DB", "Netscape Navigator (v.4) database", ["db"], ""),
FileFormat([0x00,0x11,0xAF], 0, "FLIC", "FLIC animation", ["fli"], ""),
FileFormat([0x00,0x14,0x00,0x00,0x01,0x02], 0, "BIOS details in RAM", "BIOS details in RAM", ["*"], ""),
FileFormat([0x00,0x1E,0x84,0x90,0x00,0x00,0x00,0x00], 0, "SNM", "Netscape Communicator (v.4) mail folder", ["snm"], ""),
FileFormat([0x00,0x61,0x73,0x6d], 0, "WASM", "WebAssembly binary format", ["wasm"], ""),
FileFormat([0x01,0x0F,0x00,0x00], 0, "MS SQL Server Database", "MS SQL Server Database", ["mdf"], ""),
FileFormat([0x01,0x10], 0, "TR1", "Novell LANalyzer capture file", ["tr1"], ""),
FileFormat([0x01,0xDA,0x01,0x01,0x00,0x03], 0, "RGB", "Silicon Graphics RGB Bitmap", ["rgb"], ""),
FileFormat([0x01,0xFF,0x02,0x04,0x03,0x02], 0, "DRW", "Micrografx vector graphic file", ["drw"], ""),
FileFormat([0x02,0x64,0x73,0x73], 0, "DSS", "Digital Speech Standard file", ["dss"], ""),
FileFormat([0x03], 0, "MapInfo Native Data Format", "MapInfo Native Data Format", ["dat"], ""),
FileFormat([0x03], 0, "DB3", "dBASE III file", ["db3"], ""),
FileFormat([0x03,0x00,0x00,0x00], 0, "QPH", "Quicken price history", ["qph"], ""),
FileFormat([0x03,0x00,0x00,0x00,0x41,0x50,0x50,0x52], 0, "ADX", "Approach index file", ["adx"], ""),
FileFormat([0x04], 0, "DB4", "dBASE IV file", ["db4"], ""),
FileFormat([0x04,0x00,0x00,0x00], 0, "Windows recycle bin", "INFO2 Windows recycle", ["*"], ""),
FileFormat([0x04,0x22,0x4D,0x18], 0, "LZ4", "LZ4 Frame Format", ["lz4"], "Archives"),
FileFormat([0x05,0x00,0x00,0x00], 0, "Windows recycle bin", "INFO2 Windows recycle", ["*"], ""),
FileFormat([0x05,0x07,0x00,0x00,0x42,0x4F,0x42,0x4F], 0, "CWK", "AppleWorks document", ["cwk"], ""),
FileFormat([0x06,0x07,0xE1,0x00,0x42,0x4F,0x42,0x4F], 0, "CWK", "AppleWorks document", ["cwk"], ""),
FileFormat([0x07], 0, "DRW", "Generic draw file", ["drw"], ""),
FileFormat([0x07,0x53,0x4B,0x46], 0, "SKF", "SkinCrafter skin", ["skf"], ""),
FileFormat([0x07,0x64,0x74,0x32,0x64,0x64,0x74,0x64], 0, "DTD", "DesignTools 2D Design file", ["dtd"], ""),
FileFormat([0x08], 0, "DB", "dBASE IV or dBFast configuration file", ["db"], ""),
FileFormat([0x0A,0x02,0x01], 0, "PCX", "ZSOFT Paintbrush", ["pcx"], ""),
FileFormat([0x0A,0x03,0x01], 0, "PCX", "ZSOFT Paintbrush", ["pcx"], ""),
FileFormat([0x0A,0x04,0x01], 0, "PCX", "ZSOFT Paintbrush", ["pcx"], ""),
FileFormat([0x0A,0x05,0x01], 0, "PCX", "ZSOFT Paintbrush", ["pcx"], ""),
FileFormat([0x0A,0x0D,0x0D,0x0A], 0, "PCANPG", "PCAP Next Generation Dump File Format", ["pcapng"], ""),
FileFormat([0x0C,0xED], 0, "MP", "Monochrome Picture TIFF bitmap", ["mp"], "Pictures"),
FileFormat([0x0D,0x44,0x4F,0x43], 0, "DeskMate Document", "DeskMate Document", ["doc"], ""),
FileFormat([0x0E,0x4E,0x65,0x72,0x6F,0x49,0x53,0x4F], 0, "NRI", "Nero CD compilation", ["nri"], ""),
FileFormat([0x0E,0x57,0x4B,0x53], 0, "WKS", "DeskMate Worksheet", ["wks"], ""),
FileFormat([0x53,0x43,0x43,0x41], 4, "PF", "Windows prefetch file", ["pf"], ""),
FileFormat([0x1A,0x00,0x00], 0, "Lotus Notes database template", "Lotus Notes database template", ["ntf"], ""),
FileFormat([0x1A,0x00,0x00,0x04,0x00,0x00], 0, "Lotus Notes database", "Lotus Notes database", ["nsf"], ""),
FileFormat([0x1A,0x02], 0, "ARC", "LH archive", ["arc"], "Archives"),
FileFormat([0x1A,0x03], 0, "ARC", "LH archive", ["arc"], "Archives"),
FileFormat([0x1A,0x04], 0, "ARC", "LH archive", ["arc"], "Archives"),
FileFormat([0x1A,0x08], 0, "ARC", "LH archive", ["arc"], "Archives"),
FileFormat([0x1A,0x09], 0, "ARC", "LH archive", ["arc"], "Archives"),
FileFormat([0x1A,0x0B], 0, "PAK", "PAK Compressed archive file", ["pak"], "Archives"),
FileFormat([0x1A,0x35,0x01,0x00], 0, "ETH", "WinPharoah capture file", ["eth"], ""),
FileFormat([0x1A,0x45,0xDF,0xA3], 0, "MKV", "Matroska media container", ["mkv"], "Video"),
FileFormat([0x1A,0x45,0xDF,0xA3], 0, "WEBM", "WebM video file", ["webm"], "Video"),
FileFormat([0x1A,0x52,0x54,0x53,0x20,0x43,0x4F,0x4D], 0, "Runtime Software disk image", "Runtime Software disk image", ["dat"], ""),
FileFormat([0x1B,0x4C,0x75,0x61], 0, "Lua bytecode", "Lua bytecode", ["luac"], ""),
FileFormat([0x1D,0x7D], 0, "WS", "WordStar document", ["ws"], ""),
FileFormat([0x1F,0x8B,0x08], 0, "GZIP", "GZIP archive file", ["gz", "tgz"], "Archives"),
FileFormat([0x1F,0x9D], 0, "LZV archive", "LZV archive", ["tar.z", "z"], "Archives"),
FileFormat([0x1F,0xA0], 0, "LZH archive", "LZH archive", ["tar.z", "z"], "Archives"),
FileFormat([0x20,0x02,0x01,0x62,0xA0,0x1E,0xAB,0x07,0x02,0x00,0x00,0x00], 0, "TDE", "Tableau Datasource", ["tde"], ""),
FileFormat([0x21,0x12], 0, "AIN", "AIN Compressed Archive", ["ain"], "Archives"),
FileFormat([0x21,0x3C,0x61,0x72,0x63,0x68,0x3E], 0, "DEB", "Debian package format", ["deb"], ""),
FileFormat([0x21,0x3C,0x61,0x72,0x63,0x68,0x3E,0x0A], 0, "LIB", "MS Program Library Common Object File Format", ["lib"], "Archives"),
FileFormat([0x23,0x20], 0, "Cerius2 file", "Cerius2 file", ["msi"], ""),
FileFormat([0x23,0x20,0x44,0x69,0x73,0x6B,0x20,0x44], 0, "VMDK", "VMware Virtual Disk", ["vmdk"], ""),
FileFormat([0x23,0x20,0x4D,0x69,0x63,0x72,0x6F,0x73], 0, "DSP", "MS Developer Studio project file", ["dsp"], ""),
FileFormat([0x23,0x21,0x41,0x4D,0x52], 0, "AMR", "Adaptive Multi-Rate ACELP Codec", ["amr"], "Audio"),
FileFormat([0x23,0x3F,0x52,0x41,0x44,0x49,0x41,0x4E], 0, "HDR", "Radiance High Dynamic Range image file", ["hdr"], ""),
FileFormat([0x24,0x46,0x4C,0x32,0x40,0x28,0x23,0x29], 0, "SPSS Data file", "SPSS Data file", ["sav"], ""),
FileFormat([0x24,0x53,0x44,0x49,0x30,0x30,0x30,0x31], 0, "System Deployment Image", "Disk image format used by Microsoft", ["*"], ""),
FileFormat([0x25,0x21,0x50,0x53], 0, "PS", "PostScript document", ["ps"], ""),
FileFormat([0x25,0x21,0x50,0x53,0x2D,0x41,0x64,0x6F], 0, "EPS", "Encapsulated PostScript document", ["eps"], ""),
FileFormat([0x25,0x50,0x44,0x46], 0, "PDF", "Portable Document Format", ["pdf"], "Documents"),
FileFormat([0x25,0x50,0x44,0x46], 0, "FDF", "Forms Document Format", ["fdf"], "Documents"),
FileFormat([0x25,0x50,0x44,0x46], 0, "AI", "Illustrator graphics format", ["ai"], ""),
FileFormat([0x27,0x05,0x19,0x56], 0, "U-Boot", "Das U-Boot Universal Boot Loader", ["*"], ""),
FileFormat([0x28,0x54,0x68,0x69,0x73,0x20,0x66,0x69], 0, "HQX", "BinHex 4 Compressed Archive", ["hqx"], "Archives"),
FileFormat([0x28,0xB5,0x2F,0xFD], 0, "Zstandard compressed file", "zst", ["Archives"], ""),
FileFormat([0x2A,0x2A,0x2A,0x20,0x20,0x49,0x6E,0x73], 0, "Symantec Wise Installer log", "Symantec Wise Installer log", ["log"], ""),
FileFormat([0x2D,0x6C,0x68], 2, "LHA & LHZ", "Compressed archive", ["lha", "lzh"], "Archives"),
FileFormat([0x2E,0x52,0x45,0x43], 0, "IVR", "RealPlayer video file (V11+)", ["ivr"], "Video"),
FileFormat([0x2E,0x52,0x4D,0x46], 0, "RealMedia", "RealMedia streaming media", ["rm", "rmvb"], ""),
FileFormat([0x2E,0x52,0x4D,0x46,0x00,0x00,0x00,0x12], 0, "RealAudio file", "RealAudio file", ["ra"], "Audio"),
FileFormat([0x2E,0x72,0x61,0xFD,0x00], 0, "RealAudio streaming media", "RealAudio streaming media", ["ra"], "Audio"),
FileFormat([0x2E,0x73,0x6E,0x64], 0, "AU", "NeXT|Sun Microsystems audio file", ["au"], ""),
FileFormat([0x30], 0, "CAT", "MS security catalog file", ["cat"], ""),
FileFormat([0x30,0x00,0x00,0x00,0x4C,0x66,0x4C,0x65], 0, "EVT", "Windows Event Viewer file", ["evt"], ""),
FileFormat([0x30,0x26,0xB2,0x75,0x8E,0x66,0xCF,0x11], 0, "WMV", "Windows Media Video File", ["wmv"], "Video"),
FileFormat([0x30,0x26,0xB2,0x75,0x8E,0x66,0xCF,0x11], 0, "WMA", "Windows Media Audio File", ["wma"], "Audio"),
FileFormat([0x30,0x26,0xB2,0x75,0x8E,0x66,0xCF,0x11], 0, "ASF", "Windows Media Audio|Video File", ["asf"], ""),
FileFormat([0x30,0x31,0x4F,0x52,0x44,0x4E,0x41,0x4E], 0, "NTF", "National Transfer Format Map", ["ntf"], ""),
FileFormat([0x30,0x37,0x30,0x37,0x30], 0, "cpio archive", "cpio archive", ["*"], ""),
FileFormat([0x30,0x82], 0, "DER", "DER encoded X.509 certificate", ["der"], ""),
FileFormat([0x31,0xBE], 0, "WRI", "MS Write", ["wri"], ""),
FileFormat([0x32,0xBE], 0, "WRI", "MS Write", ["wri"], ""),
FileFormat([0x34,0xCD,0xB2,0xA1], 0, "Tcpdump capture file", "Tcpdump capture file", ["*"], ""),
FileFormat([0x37,0x7A,0xBC,0xAF,0x27,0x1C], 0, "7zip", "7-Zip compressed file", ["7z"], "Archives"),
FileFormat([0x37,0xE4,0x53,0x96,0xC9,0xDB,0xD6,0x07], 0, "zisofs compressed file", "zisofs compressed file", ["*"], "Archives"),
FileFormat([0x38,0x42,0x50,0x53], 0, "PSD", "Photoshop image", ["psd"], "Pictures"),
FileFormat([0x37,0x48,0x03,0x02,0x00,0x00,0x00,0x00,0x58,0x35,0x30,0x39,0x4B,0x45,0x59], 0, "KDB", "KDB file", ["kdb"], ""),
FileFormat([0x3A,0x56,0x45,0x52,0x53,0x49,0x4F,0x4E], 0, "SLE", "Surfplan kite project file", ["sle"], ""),
FileFormat([0x3C,0x61,0x73,0x78], 0, "ASX", "Advanced Stream Redirector", ["asx"], ""),
FileFormat([0x3C,0x21,0x64,0x6F,0x63,0x74,0x79,0x70], 0, "DCI", "AOL HTML mail", ["dci"], ""),
FileFormat([0x3C,0x3F,0x78,0x6D,0x6C,0x20,0x76,0x65,0x72,0x73,0x69,0x6F,0x6E,0x3D], 0, "Windows Visual Stylesheet", "Windows Visual Stylesheet", ["manifest"], ""),
FileFormat([0x3C,0x3F,0x78,0x6D,0x6C,0x20,0x76,0x65,0x72,0x73,0x69,0x6F,0x6E,0x3D], 0, "XML", "eXtensible Markup Language", ["xml"], "Text"),
FileFormat([0x3C,0x3F,0x78,0x6D,0x6C,0x20,0x76,0x65,0x72,0x73,0x69,0x6F,0x6E,0x3D,0x22,0x31,0x2E,0x30,0x22,0x3F,0x3E,0x0D,0x0A,0x3C,0x4D,0x4D,0x43,0x5F,0x43,0x6F,0x6E,0x73,0x6F,0x6C,0x65,0x46,0x69,0x6C,0x65,0x20,0x43,0x6F,0x6E,0x73,0x6F,0x6C,0x65,0x56,0x65,0x72], 0, "MSC", "Microsoft Management Console Snap-in Control file", ["msc"], ""),
FileFormat([0x3C,0x4D,0x61,0x6B,0x65,0x72,0x46,0x69], 0, "Adobe FrameMaker", "Adobe FrameMaker", ["mif", "fm"], ""),
FileFormat([0x3E,0x00,0x03,0x00,0xFE,0xFF,0x09,0x00,0x06], 0, "WB3", "Quatro Pro for Windows 7.0", ["wb3"], ""),
FileFormat([0x3F,0x5F,0x03,0x00], 0, "HLP", "Windows Help", ["gid", "hlp"], ""),
FileFormat([0x40,0x40,0x40,0x20,0x00,0x00,0x40,0x40,0x40,0x40], 0, "ENL", "EndNote Library File", ["enl"], ""),
FileFormat([0x41,0x43], 0, "DWG", "Generic AutoCAD drawing", ["dwg"], ""),
FileFormat([0x41,0x43,0x53,0x44], 0, "AOL parameter and info files", "AOL parameter and info files", ["*"], ""),
FileFormat([0x41,0x43,0x76], 0, "SLE", "Steganos virtual secure drive", ["sle"], ""),
FileFormat([0x41,0x47,0x44,0x33], 0, "FH8", "FreeHand 8 document", ["fh8"], ""),
FileFormat([0x41,0x4D,0x59,0x4F], 0, "SYW", "Harvard Graphics symbol graphic", ["syw"], ""),
FileFormat([0x41,0x54,0x26,0x54,0x46], 0, "DJVU", "DjVu document", ["djvu", "djv"], "Documents"),
FileFormat([0x41,0x56,0x47,0x36,0x5F,0x49,0x6E,0x74], 0, "AVG6 Integrity database", "AVG6 Integrity database", ["dat"], ""),
FileFormat([0x41,0x72,0x43,0x01], 0, "ARC", "FreeArc compressed file", ["arc"], "Archives"),
FileFormat([0x42,0x45,0x47,0x49,0x4E,0x3A,0x56,0x43], 0, "VCF", "vCard", ["vcf"], ""),
FileFormat([0x42,0x50,0x47,0xFB], 0, "BPG", "Better Portable Graphics format", ["bpg"], "Pictures"),
FileFormat([0x42,0x4C,0x49,0x32,0x32,0x33], 0, "Speedtouch router firmware", "Speedtouch router firmware", ["bin", "bli", "rbi"], ""),
FileFormat([0x42,0x4D], 0, "BMP", "Bitmap image", ["bmp", "dib"], "Pictures"),
FileFormat([0x42,0x4F,0x4F,0x4B,0x4D,0x4F,0x42,0x49], 0, "PRC", "Palmpilot resource file", ["prc"], ""),
FileFormat([0x42,0x5A,0x68], 0, "BZIP2", "bzip2 compressed archive", ["bz2", "tbz2", "tb2"], "Archives"),
FileFormat([0x43,0x23,0x2B,0x44,0xA4,0x43,0x4D,0xA5], 0, "RTD", "RagTime document", ["rtd"], ""),
FileFormat([0x43,0x44,0x30,0x30,0x31], 0, "ISO", "ISO-9660 CD Disc Image", ["iso"], ""),
FileFormat([0x43,0x4D,0x58,0x31], 0, "Corel Binary metafile", "Corel Binary metafile", ["clb"], ""),
FileFormat([0x43,0x4F,0x4D,0x2B], 0, "COM+ Catalog", "COM+ Catalog", ["clb"], ""),
FileFormat([0x43,0x4F,0x57,0x44], 0, "VMDK", "VMware Virtual Disk", ["vmdk"], ""),
FileFormat([0x43,0x50,0x54,0x37,0x46,0x49,0x4C,0x45], 0, "CPT", "Corel Photopaint", ["cpt"], ""),
FileFormat([0x43,0x50,0x54,0x46,0x49,0x4C,0x45], 0, "CPT", "Corel Photopaint", ["cpt"], ""),
FileFormat([0x43,0x52,0x45,0x47], 0, "Win9x registry hive", "Win9x registry hive", ["dat"], ""),
FileFormat([0x43,0x52,0x55,0x53,0x48,0x20,0x76], 0, "CRU", "Crush compressed archive", ["cru"], "Archives"),
FileFormat([0x43,0x57,0x53], 0, "SWF", "Macromedia Shockwave Flash file format", ["swf"], ""),
FileFormat([0x43,0x61,0x74,0x61,0x6C,0x6F,0x67,0x20], 0, "CTF", "WhereIsIt Catalog", ["ctf"], ""),
FileFormat([0x43,0x6C,0x69,0x65,0x6E,0x74,0x20,0x55], 0, "IE cache file", "IE cache file", ["dat"], ""),
FileFormat([0x43,0x72,0x32,0x34], 0, "CRX", "Google Chrome extension or packaged app", ["crx"], ""),
FileFormat([0x44,0x42,0x46,0x48], 0, "Palm Zire photo database", "Palm Zire photo database", ["db"], ""),
FileFormat([0x44,0x4D,0x53,0x21], 0, "DMS", "Amiga DiskMasher compressed archive", ["dms"], "Archives"),
FileFormat([0x44,0x4F,0x53], 0, "ADF", "Amiga disk file", ["adf"], ""),
FileFormat([0x44,0x56,0x44], 0, "IFO", "DVD info file", ["ifo"], ""),
FileFormat([0x44,0x56,0x44], 0, "DVR", "DVR-Studio stream file", ["dvr"], ""),
FileFormat([0x45,0x4C,0x49,0x54,0x45,0x20,0x43,0x6F], 0, "CDR", "Elite Plus Commander game file", ["cdr"], ""),
FileFormat([0x45,0x4E,0x54,0x52,0x59,0x56,0x43,0x44], 0, "VCD", "VideoVCD|VCDImager file", ["vcd"], ""),
FileFormat([0x45,0x50], 0, "MDI", "MS Document Imaging file", ["mdi"], ""),
FileFormat([0x45,0x52,0x46,0x53,0x53,0x41,0x56,0x45], 0, "EasyRecovery Saved State file", "EasyRecovery Saved State file", ["dat"], ""),
FileFormat([0x45,0x56,0x46,0x09,0x0D,0x0A,0xFF,0x00], 0, "E01", "Expert Witness Compression Format", ["e01"], ""),
FileFormat([0x45,0x6C,0x66,0x46,0x69,0x6C,0x65,0x00], 0, "EVTX", "Windows Vista event log", ["evtx"], ""),
FileFormat([0x45,0x86,0x00,0x00,0x06,0x00], 0, "QBB", "QuickBooks backup", ["qbb"], ""),
FileFormat([0x46,0x41,0x58,0x43,0x4F,0x56,0x45,0x52], 0, "CPE", "MS Fax Cover Sheet", ["cpe"], ""),
FileFormat([0x46,0x4C,0x49,0x46], 0, "FLIF", "Free Lossless Image Format", ["flif"], "Pictures"),
FileFormat([0x46,0x4C,0x56], 0, "FLV", "Flash video file", ["flv"], "Video"),
FileFormat([0x4C,0x5A,0x49,0x50], 0, "LZIP", "LZIP compressed file format", ["lz"], "Archives"),
FileFormat([0x46,0x4F,0x52,0x4D,0x00], 0, "AIFF", "Audio Interchange File", ["aiff"], "Audio"),
FileFormat([0x46,0x57,0x53], 0, "SWF", "Macromedia Shockwave Flash file format", ["swf"], ""),
FileFormat([0x46,0x72,0x6F,0x6D], 0, "EML", "Generic e-mail format", ["eml"], ""),
FileFormat([0x47,0x49,0x46,0x38], 0, "GIF", "GIF file", ["gif"], "Pictures"),
FileFormat([0x47,0x50,0x41,0x54], 0, "PAT", "GIMP pattern file", ["pat"], ""),
FileFormat([0x48,0x48,0x47,0x42,0x31], 0, "SH3", "Harvard Graphics presentation file", ["sh3"], ""),
FileFormat([0x48,0x69,0x50,0x21], 0, "HIP", "Houdini image file", ["hip"], ""),
FileFormat([0x49,0x20,0x49], 0, "TIFF", "TIFF image", ["tif", "tiff"], "Pictures"),
FileFormat([0x49,0x49,0x2A,0x00], 0, "TIFF", "TIFF image", ["tif", "tiff"], "Pictures"),
FileFormat([0x49,0x44,0x33], 0, "MP3", "MP3 audio file", ["mp3"], "Audio"),
FileFormat([0x49,0x44,0x33,0x03,0x00,0x00,0x00], 0, "KOZ", "Sprint Music Store audio", ["koz"], "Audio"),
FileFormat([0x49,0x49,0x1A,0x00,0x00,0x00,0x48,0x45], 0, "CRW", "Canon RAW file", ["crw"], ""),
FileFormat([0x49,0x53,0x63,0x28], 0, "Install Shield compressed file", "Install Shield compressed file", ["cab", "hdr"], ""),
FileFormat([0x49,0x54,0x4F,0x4C,0x49,0x54,0x4C,0x53], 0, "LIT", "MS Reader eBook", ["lit"], ""),
FileFormat([0x49,0x54,0x53,0x46], 0, "CHM", "MS Compiled HTML Help File", ["chi", "chm"], ""),
FileFormat([0x49,0x6E,0x6E,0x6F,0x20,0x53,0x65,0x74], 0, "Inno Setup Uninstall Log", "Inno Setup Uninstall Log", ["dat"], ""),
FileFormat([0x4A,0x41,0x52,0x43,0x53,0x00], 0, "JARCS compressed archive", "JARCS compressed archive", ["jar"], "Archives"),
FileFormat([0x4A,0x47,0x03,0x0E], 0, "JG", "AOL ART", ["jg"], ""),
FileFormat([0x4A,0x47,0x04,0x0E], 0, "JG", "AOL ART", ["jg"], ""),
FileFormat([0x4B,0x44,0x4D], 0, "VMDK", "VMware Virtual Disk", ["vmdk"], ""),
FileFormat([0x4B,0x47,0x42,0x5F,0x61,0x72,0x63,0x68], 0, "KGB", "KGB archive", ["kgb"], "Archives"),
FileFormat([0x4B,0x49,0x00,0x00], 0, "SHD", "Win9x printer spool file", ["shd"], ""),
FileFormat([0x4B,0x57,0x41,0x4A,0x88,0xF0,0x27,0xD1], 0, "KWAJ", "KWAJ compressed file", ["*"], ""),
FileFormat([0x4C,0x00,0x00,0x00,0x01,0x14,0x02,0x00], 0, "LNK", "Windows shortcut file", ["lnk"], ""),
FileFormat([0x4C,0x01], 0, "OBJ", "MS Common Object File Format", ["obj"], ""),
FileFormat([0x4C,0x4E,0x02,0x00], 0, "HLP", "Windows help", ["hlp", "gid"], ""),
FileFormat([0x4C,0x56,0x46,0x09,0x0D,0x0A,0xFF,0x00], 0, "E01", "Logical File Evidence Format", ["e01"], ""),
FileFormat([0x4D,0x2D,0x57,0x20,0x50,0x6F,0x63,0x6B], 0, "PDB", "Merriam-Webster Pocket Dictionary", ["pdb"], ""),
FileFormat([0x4D,0x41,0x52,0x31,0x00], 0, "MAR", "Mozilla archive", ["mar"], "Archives"),
FileFormat([0x4D,0x41,0x52,0x43], 0, "MAR", "Microsoft|MSN MARC archive", ["mar"], ""),
FileFormat([0x4D,0x41,0x72,0x30,0x00], 0, "MAR", "MAr compressed archive", ["mar"], "Archives"),
FileFormat([0x4D,0x44,0x4D,0x50,0x93,0xA7], 0, "Windows dump file", "Windows dump file", ["hdmp", "dmp"], ""),
FileFormat([0x4D,0x49,0x4C,0x45,0x53], 0, "Milestones project management file", "Milestones project management file", ["mls"], ""),
FileFormat([0x4D,0x4C,0x53,0x57], 0, "Skype localization data file", "Skype localization data file", ["mls"], ""),
FileFormat([0x4D,0x4C,0x56,0x49], 0, "MLV", "Magic Lantern Video format", ["mlv"], "Video"),
FileFormat([0x4D,0x4D,0x00,0x2A], 0, "TIFF", "TIFF image", ["tiff", "tif"], "Pictures"),
FileFormat([0x4D,0x4D,0x00,0x2B], 0, "TIFF", "TIFF image", ["tiff", "tif"], "Pictures"),
FileFormat([0x4D,0x4D,0x4D,0x44,0x00,0x00], 0, "MMF", "Yamaha Synthetic music Mobile Application Format", ["mmf"], "Audio"),
FileFormat([0x4D,0x52,0x56,0x4E], 0, "NVRAM", "VMware BIOS state file", ["nvram"], ""),
FileFormat([0x4D,0x53,0x43,0x46], 0, "CAB", "Microsoft cabinet file", ["cab"], ""),
FileFormat([0x4D,0x53,0x43,0x46], 0, "SNP", "MS Access Snapshot Viewer file", ["snp"], ""),
FileFormat([0x4D,0x53,0x43,0x46], 0, "PPZ", "Powerpoint Packaged Presentation", ["ppz"], ""),
FileFormat([0x4D,0x53,0x46,0x54,0x02,0x00,0x01,0x00], 0, "TLB", "OLE|SPSS|Visual C++ library file", ["tlb"], ""),
FileFormat([0x4D,0x53,0x5F,0x56,0x4F,0x49,0x43,0x45], 0, "Sony Compressed Voice File", "Sony Compressed Voice File", ["dvf", "cdr", "msv"], ""),
FileFormat([0x4D,0x54,0x68,0x64], 0, "MIDI", "MIDI sound file", ["midi", "mid"], "Audio"),
FileFormat([0x4D,0x56], 0, "DSN", "CD Stomper Pro label file", ["dsn"], ""),
FileFormat([0x4D,0x56,0x32,0x31,0x34], 0, "MLS", "Milestones project management", ["mls"], ""),
FileFormat([0x4D,0x56,0x32,0x43], 0, "MLS", "Milestones project management", ["mls"], ""),
FileFormat([0x4D,0x5A], 0, "VBX", "VisualBASIC application", ["vbx"], ""),
FileFormat([0x4D,0x5A], 0, "Windows|DOS executable file", "Windows|DOS executable file", ["com", "dll", "drv", "exe", "pif", "qts", "qtx", "sys"], ""),
FileFormat([0x4D,0x5A], 0, "OLB", "OLE object library", ["olb"], ""),
FileFormat([0x4D,0x5A], 0, "AX", "Library cache file", ["ax"], ""),
FileFormat([0x4D,0x5A], 0, "SCR", "Screen saver", ["scr"], ""),
FileFormat([0x4D,0x5A], 0, "OCX", "ActiveX|OLE Custom Control", ["ocx"], ""),
FileFormat([0x4D,0x5A], 0, "OLB", "OLE object library", ["olb"], ""),
FileFormat([0x4D,0x5A], 0, "SCR", "Screen saver", ["scr"], ""),
FileFormat([0x4D,0x5A], 0, "OCX", "ActiveX|OLE Custom Control", ["ocx"], ""),
FileFormat([0x4D,0x5A], 0, "ACM", "MS audio compression manager driver", ["acm"], ""),
FileFormat([0x4D,0x5A], 0, "CPL", "Control panel application", ["cpl"], ""),
FileFormat([0x4D,0x5A], 0, "Windows virtual device drivers", "Windows virtual device drivers", ["386", "vxd"], ""),
FileFormat([0x4D,0x5A], 0, "FON", "Font file", ["fon"], ""),
FileFormat([0x4D,0x5A,0x90,0x00,0x03,0x00,0x00,0x00], 0, "FLT", "Audition graphic filter", ["flt"], ""),
FileFormat([0x4D,0x5A,0x90,0x00,0x03,0x00,0x00,0x00], 0, "AX", "DirectShow filter", ["ax"], ""),
FileFormat([0x4D,0x5A,0x90,0x00,0x03,0x00,0x00,0x00], 0, "API", "Acrobat plug-in", ["api"], ""),
FileFormat([0x4D,0x5A,0x90,0x00,0x03,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0xFF,0xFF], 0, "ZAP", "ZoneAlam data file", ["zap"], ""),
FileFormat([0x4D,0x69,0x63,0x72,0x6F,0x73,0x6F,0x66,0x74,0x20,0x43,0x2F,0x43,0x2B,0x2B,0x20], 0, "PDB", "MS C++ debugging symbols file", ["pdb"], ""),
FileFormat([0x4D,0x69,0x63,0x72,0x6F,0x73,0x6F,0x66,0x74,0x20,0x56,0x69,0x73,0x75,0x61,0x6C], 0, "SLN", "Visual Studio .NET file", ["sln"], ""),
FileFormat([0x4D,0x69,0x63,0x72,0x6F,0x73,0x6F,0x66,0x74,0x20,0x57,0x69,0x6E,0x64,0x6F,0x77,0x73,0x20,0x4D,0x65,0x64,0x69,0x61,0x20,0x50,0x6C,0x61,0x79,0x65,0x72,0x20,0x2D,0x2D,0x20], 0, "WPL", "Windows Media Player playlist", ["wpl"], ""),
FileFormat([0x4E,0x41,0x56,0x54,0x52,0x41,0x46,0x46,0x49,0x43], 0, "TomTom traffic data", "TomTom traffic data", ["dat"], ""),
FileFormat([0x4E,0x42,0x2A,0x00], 0, "MS Windows journal", "MS Windows journal", ["jtp", "jnt"], ""),
FileFormat([0x4E,0x45,0x53,0x1A], 0, "NES", "Nintendo Entertainment System ROM file", ["nes"], ""),
FileFormat([0x4E,0x45,0x53,0x4D,0x1A,0x01], 0, "NSF", "NES Sound file", ["nsf"], ""),
FileFormat([0x4E,0x49,0x54,0x46,0x30], 0, "NTF", "National Imagery Transmission Format file", ["ntf"], ""),
FileFormat([0x4E,0x61,0x6D,0x65,0x3A,0x20], 0, "COD", "Agent newsreader character map", ["cod"], ""),
FileFormat([0x4F,0x50,0x4C,0x44,0x61,0x74,0x61,0x62], 0, "DBF", "Psion Series 3 Database", ["dbf"], ""),
FileFormat([0x4F,0x54,0x54,0x4F,0x00], 0, "OTF", "OpenType font format", ["otf"], ""),
FileFormat([0x4F,0x67,0x67,0x53,0x00,0x02,0x00,0x00], 0, "OGG", "Ogg Vorbis Codec compressed file", ["oga", "ogg", "ogv", "ogx"], "Audio"),
FileFormat([0x4F,0x7B], 0, "DW4", "Visio|DisplayWrite 4 text file", ["dw4"], ""),
FileFormat([0x50,0x00,0x00,0x00,0x20,0x00,0x00,0x00], 0, "IDX", "Quicken QuickFinder Information File", ["idx"], ""),
FileFormat([0x50,0x35,0x0A], 0, "PGM", "Portable Graymap Graphic", ["pgm"], ""),
FileFormat([0x50,0x41,0x43,0x4B], 0, "Quake archive file", "Quake archive file", ["pak"], "Archives"),
FileFormat([0x50,0x41,0x47,0x45,0x44,0x55], 0, "DMP", "Windows memory dump", ["dmp"], ""),
FileFormat([0x50,0x41,0x58], 0, "PAX", "PAX password protected bitmap", ["pax"], ""),
FileFormat([0x50,0x45,0x53,0x54], 0, "PestPatrol data|scan strings", "PestPatrol data|scan strings", ["dat"], ""),
FileFormat([0x50,0x47,0x50,0x64,0x4D,0x41,0x49,0x4E], 0, "PGD", "PGP disk image", ["pgd"], ""),
FileFormat([0x50,0x49,0x43,0x54,0x00,0x08], 0, "ChromaGraph Graphics Card Bitmap", "ChromaGraph Graphics Card Bitmap", ["img"], ""),
FileFormat([0x50,0x4B,0x03,0x04], 0, "ZIP", "PKZIP", ["zip"], "Archives"),
FileFormat([0x50,0x4B,0x03,0x04], 0, "JAR", "Java archive", ["jar"], "Archives"),
FileFormat([0x50,0x4B,0x03,0x04], 0, "KMZ", "Google Earth saved working session", ["kmz"], ""),
FileFormat([0x50,0x4B,0x03,0x04], 0, "KWD", "KWord document", ["kwd"], ""),
FileFormat([0x50,0x4B,0x03,0x04], 0, "ODT", "OpenDocument text document", ["odt"], "Documents"),
FileFormat([0x50,0x4B,0x03,0x04], 0, "ODS", "OpenDocument table", ["ods"], "Documents"),
FileFormat([0x50,0x4B,0x03,0x04], 0, "ODP", "OpenDocument presentation", ["odp"], "Documents"),
FileFormat([0x50,0x4B,0x03,0x04], 0, "OTT", "OpenDocument text template", ["ott"], ""),
FileFormat([0x50,0x4B,0x03,0x04], 0, "OXPS", "Microsoft Open XML paper specification", ["oxps"], ""),
FileFormat([0x50,0x4B,0x03,0x04], 0, "SXC", "StarOffice spreadsheet", ["sxc"], ""),
FileFormat([0x50,0x4B,0x03,0x04], 0, "WMZ", "Windows Media compressed skin file", ["wmz"], ""),
FileFormat([0x50,0x4B,0x03,0x04], 0, "XPI", "Mozilla Browser Archive", ["xpi"], "Archives"),
FileFormat([0x50,0x4B,0x03,0x04], 0, "XPS", "XML paper specification", ["xps"], ""),
FileFormat([0x50,0x4B,0x03,0x04], 0, "XPT", "eXact Packager Models", ["xpt"], ""),
FileFormat([0x50,0x4B,0x03,0x04], 0, "CUIX", "Customization files", ["cuix"], ""),
FileFormat([0x50,0x4B,0x03,0x04,0x14,0x00,0x06,0x00], 0, "DOCX", "MS Office Word Document", ["docx"], "Documents"),
FileFormat([0x50,0x4B,0x03,0x04,0x14,0x00,0x06,0x00], 0, "XLSX", "MS Office Excel Table", ["xlsx"], "Documents"),
FileFormat([0x50,0x4B,0x03,0x04,0x14,0x00,0x06,0x00], 0, "PPTX", "MS Office PowerPoint Presentation", ["pptx"], "Documents"),
FileFormat([0x50,0x4B,0x05,0x06], 0, "ZIP", "PKZIP", ["zip"], "Archives"),
FileFormat([0x50,0x4B,0x07,0x08], 0, "ZIP", "PKZIP", ["zip"], "Archives"),
FileFormat([0x50,0x4B,0x4C,0x49,0x54,0x45], 0, "PKLITE", "PKLITE archive", ["zip"], "Archives"),
FileFormat([0x50,0x4B,0x53,0x70,0x58], 0, "PKSFX", "PKSFX self-extracting archive", ["zip"], "Archives"),
FileFormat([0x50,0x4D,0x43,0x43], 0, "GRP", "Windows Program Manager group file", ["grp"], ""),
FileFormat([0x51,0x45,0x4C,0x20], 0, "QEL", "QDL Quicken data", ["qel"], ""),
FileFormat([0x51,0x46,0x49], 0, "Qcow Disk Image", "Qcow Disk Image", ["qemu", "img"], ""),
FileFormat([0x51,0x57,0x20,0x56,0x65,0x72,0x2E,0x20], 0, "Quicken data file", "Quicken data file", ["abd,qsd"], ""),
FileFormat([0x52,0x41,0x5A,0x41,0x54,0x44,0x42,0x31], 0, "Shareaza (P2P) thumbnail", "Shareaza (P2P) thumbnail", ["dat"], ""),
FileFormat([0x52,0x44,0x58,0x32,0x0A], 0, "RDATA", "R saved work space", ["rdata"], ""),
FileFormat([0x52,0x45,0x47,0x45,0x44,0x49,0x54], 0, "REG", "WinNT Registry|Registry Undo files", ["reg", "sud"], ""),
FileFormat([0x52,0x45,0x56,0x4E,0x55,0x4D,0x3A,0x2C], 0, "Antenna data file", "Antenna data file", ["ad", "adf"], ""),
FileFormat([0x52,0x49,0x46,0x46], 0, "4XM", "4X Movie video", ["4xm"], "Video"),
FileFormat([0x52,0x49,0x46,0x46], 0, "Video CD MPEG movie", "Video CD MPEG movie", ["dat"], "Video"),
FileFormat([0x52,0x49,0x46,0x46], 0, "CMX", "Corel Presentation Exchange metadata", ["cmx"], ""),
FileFormat([0x52,0x49,0x46,0x46], 0, "CDR", "CorelDraw document", ["cdr"], ""),
FileFormat([0x52,0x49,0x46,0x46], 0, "DS4", "Micrografx Designer graphic", ["ds4"], ""),
FileFormat([0x52,0x49,0x46,0x46], 0, "AVI", "Audio Video Interleave video format", ["avi"], "Video"),
FileFormat([0x52,0x49,0x46,0x46], 0, "ANI", "Windows animated cursor", ["ani"], ""),
FileFormat([0x52,0x49,0x46,0x46], 0, "CDA", "Resource Interchange File Format", ["cda"], ""),
FileFormat([0x52,0x49,0x46,0x46], 0, "QCP", "Resource Interchange File Format", ["qcp"], ""),
FileFormat([0x52,0x49,0x46,0x46], 0, "RMI", "Resource Interchange File Format", ["rmi"], ""),
FileFormat([0x52,0x49,0x46,0x46], 0, "WAV", "Waveform Audio File Format", ["wav"], "Audio"),
FileFormat([0x52,0x54,0x53,0x53], 0, "CAP", "WinNT Netmon capture file", ["cap"], ""),
FileFormat([0x52,0x61,0x72,0x21,0x1A,0x07], 0, "RAR", "WinRAR compressed archive", ["rar"], "Archives"),
FileFormat([0x52,0x65,0x74,0x75,0x72,0x6E,0x2D,0x50], 0, "EML", "Generic e-mail format", ["eml"], ""),
FileFormat([0x53,0x43,0x48,0x6C], 0, "AST", "Underground Audio", ["ast"], "Audio"),
FileFormat([0x53,0x43,0x4D,0x49], 0, "Img Software Bitmap", "Img Software Bitmap", ["img"], "Pictures"),
FileFormat([0x53,0x48,0x4F,0x57], 0, "SHW", "Harvard Graphics presentation", ["shw"], ""),
FileFormat([0x53,0x49,0x45,0x54,0x52,0x4F,0x4E,0x49], 0, "CPI", "Sietronics CPI XRD document", ["cpi"], ""),
FileFormat([0x53,0x49,0x54,0x21,0x00], 0, "SIT", "StuffIt compressed archive", ["sit"], "Archives"),
FileFormat([0x53,0x4D,0x41,0x52,0x54,0x44,0x52,0x57], 0, "SDR", "SmartDraw Drawing file", ["sdr"], ""),
FileFormat([0x53,0x51,0x4C,0x4F,0x43,0x4F,0x4E,0x56], 0, "CNV", "DB2 conversion file", ["cnv"], ""),
FileFormat([0x53,0x51,0x4C,0x69,0x74,0x65,0x20,0x66,0x6F,0x72,0x6D,0x61,0x74,0x20,0x33,0x00], 0, "SQLite Database", "SQLite database file format", ["db", "sqlitedb", "sqlite"], ""),
FileFormat([0x53,0x5A,0x20,0x88,0xF0,0x27,0x33,0xD1], 0, "QBASIC SZDD file", "QBASIC SZDD file", ["*"], ""),
FileFormat([0x53,0x5A,0x44,0x44,0x88,0xF0,0x27,0x33], 0, "SZDD file format", "SZDD file format", ["*"], ""),
FileFormat([0x53,0x74,0x75,0x66,0x66,0x49,0x74,0x20], 0, "SIT", "StuffIt compressed archive", ["sit"], "Archives"),
FileFormat([0x53,0x75,0x70,0x65,0x72,0x43,0x61,0x6C], 0, "CAL", "SuperCalc worksheet", ["cal"], "Archives"),
FileFormat([0x54,0x44,0x45,0x46], 0, "TDEF", "Telegram Desktop Encrypted File", ["tdef"], ""),
FileFormat([0x54,0x68,0x69,0x73,0x20,0x69,0x73,0x20], 0, "INFO", "GNU Info Reader file", ["info"], ""),
FileFormat([0x55,0x43,0x45,0x58], 0, "UCE", "Unicode extensions", ["uce"], ""),
FileFormat([0x55,0x46,0x41,0xC6,0xD2,0xC1], 0, "UFA", "UFA compressed archive", ["ufa"], "Archives"),
FileFormat([0x55,0x46,0x4F,0x4F,0x72,0x62,0x69,0x74], 0, "UFO Capture map file", "UFO Capture map file", ["dat"], ""),
FileFormat([0x56,0x43,0x50,0x43,0x48,0x30], 0, "PCH", "Visual C PreCompiled header", ["pch"], ""),
FileFormat([0x56,0x45,0x52,0x53,0x49,0x4F,0x4E,0x20], 0, "CTL", "Visual Basic User-defined Control file", ["ctl"], ""),
FileFormat([0x56,0x65,0x72,0x73,0x69,0x6F,0x6E,0x20], 0, "MIF", "MapInfo Interchange Format file", ["mif"], ""),
FileFormat([0x57,0x4D,0x4D,0x50], 0, "Walkman MP3", "Walkman MP3 container file", ["dat"], "Audio"),
FileFormat([0x57,0x53,0x32,0x30,0x30,0x30], 0, "WS2", "WordStar for Windows file", ["ws2"], ""),
FileFormat([0x57,0x69,0x6E,0x5A,0x69,0x70], 0, "ZIP", "WinZip compressed archive", ["zip"], "Archives"),
FileFormat([0x57,0x6F,0x72,0x64,0x50,0x72,0x6F], 0, "LWP", "Lotus WordPro file", ["lwp"], ""),
FileFormat([0x58,0x2D], 0, "Exchange e-mail", "Exchange e-mail", ["eml"], ""),
FileFormat([0x58,0x43,0x50,0x00], 0, "CAP", "Packet sniffer files", ["cap"], ""),
FileFormat([0x58,0x50,0x43,0x4F,0x4D,0x0A,0x54,0x79], 0, "XPT", "XPCOM libraries", ["xpt"], ""),
FileFormat([0x58,0x54], 0, "BDR", "MS Publisher border", ["bdr"], ""),
FileFormat([0x5A,0x4F,0x4F,0x20], 0, "ZOO", "ZOO compressed archive", ["zoo"], "Archives"),
FileFormat([0x5A,0x57,0x53], 0, "SWF", "Macromedia Shockwave Flash file", ["swf"], ""),
FileFormat([0x5B,0x47,0x65,0x6E,0x65,0x72,0x61,0x6C], 0, "ECF", "MS Exchange configuration file", ["ecf"], ""),
FileFormat([0x5B,0x4D,0x53,0x56,0x43], 0, "VCW", "Visual C++ Workbench Info File", ["vcw"], ""),
FileFormat([0x5B,0x50,0x68,0x6F,0x6E,0x65,0x5D], 0, "DUN", "Dial-up networking file", ["dun"], ""),
FileFormat([0x5B,0x56,0x45,0x52,0x5D], 0, "SAM", "Lotus AMI Pro document", ["sam"], ""),
FileFormat([0x5B,0x5A,0x6F,0x6E,0x65], 0, "Identifier", "Microsoft Zone Identifier for URL Security Zones", ["Identifier"], ""),
FileFormat([0x5B,0x76,0x65,0x72,0x5D], 0, "SAM", "Lotus AMI Pro document", ["sam"], ""),
FileFormat([0x5B,0x57,0x69,0x6E,0x64,0x6F,0x77,0x73], 0, "CPX", "Microsoft Code Page Translation file", ["cpx"], ""),
FileFormat([0x5B,0x66,0x6C,0x74,0x73,0x69,0x6D,0x2E], 0, "CFG", "Flight Simulator Aircraft Configuration", ["cfg"], ""),
FileFormat([0x5F,0x27,0xA8,0x89], 0, "Jar archive", "Jar archive", ["jar"], "Archives"),
FileFormat([0x5F,0x43,0x41,0x53,0x45,0x5F], 0, "CAS", "EnCase case file", ["cas", "cbk"], ""),
FileFormat([0x60,0xEA], 0, "ARJ", "ARJ Compressed archive file", ["arj"], "Archives"),
FileFormat([0x62,0x65,0x67,0x69,0x6E], 0, "UUencoded file", "UUencoded file", ["*"], ""),
FileFormat([0x62,0x6F,0x6F,0x6B,0x00], 0, "macOS file Alias", "macOS file Alias", ["alias"], ""),
FileFormat([0x62,0x70,0x6C,0x69,0x73,0x74], 0, "plist", "Binary property list (plist)", ["*"], ""),
FileFormat([0x63,0x6F,0x6E,0x65,0x63,0x74,0x69,0x78], 0, "VHD", "Virtual PC HD image", ["vhd"], ""),
FileFormat([0x63,0x75,0x73,0x68,0x00,0x00,0x00,0x02], 0, "CSH", "Photoshop Custom Shape", ["csh"], ""),
FileFormat([0x64,0x00,0x00,0x00], 0, "P10", "Intel PROset|Wireless Profile", ["p10"], ""),
FileFormat([0x64,0x65,0x78,0x0A], 0, "DEX", "Dalvik (Android) executable file format", ["dex"], ""),
FileFormat([0x64,0x6E,0x73,0x2E], 0, "AU", "Audacity audio file", ["au"], "Audio"),
FileFormat([0x64,0x73,0x77,0x66,0x69,0x6C,0x65], 0, "DSW", "MS Visual Studio workspace file", ["dsw"], ""),
FileFormat([0x66,0x49,0x00,0x00], 0, "SHD", "WinNT printer spool file", ["shd"], ""),
FileFormat([0x66,0x4C,0x61,0x43,0x00,0x00,0x00,0x22], 0, "FLAC", "Free Lossless Audio Codec file", ["flac"], "Audio"),
FileFormat([0x66,0x74,0x79,0x70,0x33,0x67,0x70], 4, "3GP", "3GP", ["3gg", "3gp", "3g2"], "Video"),
FileFormat([0x66,0x72,0x65,0x65], 4, "MOV", "QuickTime movie", ["mov"], "Video"),
FileFormat([0x66,0x74,0x79,0x70], 4, "M4A", "Apple Lossless Audio Codec format", ["m4a"], "Audio"),
FileFormat([0x66,0x74,0x79,0x70,0x4D,0x34,0x56,0x20], 4, "FLV", "ISO Media, MPEG v4 system, or iTunes AVC-LC file", ["flv", "m4v"], "Video"),
FileFormat([0x66,0x74,0x79,0x70], 4, "MP4", "MPEG-4 video format", ["mp4"], "Video"),
FileFormat([0x66,0x74,0x79,0x70,0x6D,0x70,0x34,0x32], 4, "M4V", "MPEG-4 video | QuickTime", ["m4v"], "Video"),
FileFormat([0x66,0x74,0x79,0x70,0x71,0x74,0x20,0x20], 4, "MOV", "QuickTime movie", ["mov"], "Video"),
FileFormat([0x67,0x49,0x00,0x00], 0, "SHD", "Win2000|XP printer spool file", ["shd"], ""),
FileFormat([0x68,0x49,0x00,0x00], 0, "SHD", "Win Server 2003 printer spool file", ["shd"], ""),
FileFormat([0x67,0x69,0x6d,0x70,0x20,0x78,0x63,0x66,0x20], 0, "XCF", "GIMP eXperimental Computing Facility image format", ["xcf"], "Pictures"),
FileFormat([0x6C,0x33,0x33,0x6C], 0, "DBB", "Skype user data file", ["dbb"], ""),
FileFormat([0x6D,0x64,0x61,0x74], 4, "MOV", "QuickTime movie", ["mov"], "Video"),
FileFormat([0x6D,0x6F,0x6F,0x76], 4, "MOV", "QuickTime movie", ["mov"], "Video"),
FileFormat([0x6F,0x3C], 0, "SMS", "SMS text (SIM)", ["*"], ""),
FileFormat([0x70,0x6E,0x6F,0x74], 4, "MOV", "QuickTime movie", ["mov"], "Video"),
FileFormat([0x72,0x65,0x67,0x66], 0, "WinNT registry file", "WinNT registry file", ["dat"], ""),
FileFormat([0x72,0x69,0x66,0x66], 0, "Sonic Foundry Acid Music", "Sonic Foundry Acid Music Format", ["ac", "acd"], ""),
FileFormat([0x72,0x74,0x73,0x70,0x3A,0x2F,0x2F], 0, "RAM", "RealMedia metafile", ["ram"], ""),
FileFormat([0x73,0x6B,0x69,0x70], 4, "MOV", "QuickTime movie", ["mov"], "Video"),
FileFormat([0x73,0x6C,0x68,0x21], 0, "Allegro Generic Packfile", "Allegro Generic Packfile (compressed)", ["dat"], "Archives"),
FileFormat([0x73,0x6C,0x68,0x2E], 0, "Allegro Generic Packfile", "Allegro Generic Packfile (uncompressed)", ["dat"], "Archives"),
FileFormat([0x73,0x6D,0x5F], 0, "PDB", "PalmOS SuperMemo", ["pdb"], ""),
FileFormat([0x73,0x72,0x63,0x64,0x6F,0x63,0x69,0x64], 0, "CAL", "CALS raster bitmap", ["cal"], ""),
FileFormat([0x73,0x7A,0x65,0x7A], 0, "PDB", "PowerBASIC Debugger Symbols", ["pdb"], ""),
FileFormat([0x74,0x42,0x4D,0x50,0x4B,0x6E,0x57,0x72], 0, "PRC", "PathWay Map file", ["prc"], ""),
FileFormat([0x74,0x72,0x75,0x65,0x00], 0, "TTF", "TrueType font format", ["ttf"], ""),
FileFormat([0x75,0x73,0x74,0x61,0x72], 257, "TAR", "Tape Archive", ["tar"], "Archives"),
FileFormat([0x76,0x32,0x30,0x30,0x33,0x2E,0x31,0x30], 0, "FLT", "Qimage filter", ["flt"], ""),
FileFormat([0x77,0x69,0x64,0x65], 4, "MOV", "QuickTime movie", ["mov"], "Video"),
FileFormat([0x78,0x01,0x73,0x0D,0x62,0x62,0x60], 0, "DMG", "MacOS X disk image", ["dmg"], ""),
FileFormat([0x78,0x61,0x72,0x21], 0, "XAR", "eXtensible ARchive format", ["xar"], ""),
FileFormat([0x7A,0x62,0x65,0x78], 0, "ZoomBrowser Image Index", "ZoomBrowser Image Index", ["info"], ""),
FileFormat([0x7B,0x0D,0x0A,0x6F,0x20], 0, "Windows application log", "Windows application log", ["lgc", "lgd"], ""),
FileFormat([0x7B,0x5C,0x70,0x77,0x69], 0, "PWI", "MS WinMobile personal note", ["pwi"], ""),
FileFormat([0x7B,0x5C,0x72,0x74,0x66], 0, "RTF", "RTF text format", ["rtf"], "Documents"),
FileFormat([0x7E,0x42,0x4B,0x00], 0, "PSP", "Corel Paint Shop Pro image", ["psp"], "Pictures"),
FileFormat([0x7F,0x45,0x4C,0x46], 0, "ELF executable", "ELF executable", ["*"], ""),
FileFormat([0x80], 0, "OBJ", "Relocatable object code", ["obj"], ""),
FileFormat([0x80,0x00,0x00,0x20,0x03,0x12,0x04], 0, "ADX", "Dreamcast audio", ["adx"], "Audio"),
FileFormat([0x81,0x32,0x84,0xC1,0x85,0x05,0xD0,0x11], 0, "WAB", "Outlook Express address book (Win95)", ["wab"], ""),
FileFormat([0x81,0xCD,0xAB], 0, "WPF", "WordPerfect text", ["wpf"], "Documents"),
FileFormat([0x89,0x50,0x4E,0x47,0x0D,0x0A,0x1A,0x0A], 0, "PNG", "Portable Network Graphics format", ["png"], "Pictures"),
FileFormat([0x8A,0x01,0x09,0x00,0x00,0x00,0xE1,0x08], 0, "AW", "MS Answer Wizard", ["aw"], ""),
FileFormat([0x91,0x33,0x48,0x46], 0, "HAP", "Hamarsoft compressed archive", ["hap"], "Archives"),
FileFormat([0x95,0x00], 0, "SKR", "PGP secret", ["skr"], ""),
FileFormat([0x95,0x01], 0, "SKR", "PGP secret", ["skr"], ""),
FileFormat([0x99], 0, "GPG", "GPG public keyring", ["gpg"], ""),
FileFormat([0x99,0x01], 0, "PKR", "PGP public keyring", ["pkr"], ""),
FileFormat([0x9C,0xCB,0xCB,0x8D,0x13,0x75,0xD2,0x11], 0, "WAB", "Outlook address file", ["wab"], ""),
FileFormat([0xA1,0xB2,0xC3,0xD4], 0, "tcpdump", "tcpdump (libpcap) capture file", ["*"], ""),
FileFormat([0xA1,0xB2,0xCD,0x34], 0, "Extended tcpdump", "Extended tcpdump (libpcap) capture file", ["*"], ""),
FileFormat([0xA9,0x0D,0x00,0x00,0x00,0x00,0x00,0x00], 0, "Access Data FTK evidence", "Access Data FTK evidence", ["dat"], ""),
FileFormat([0xAC,0x9E,0xBD,0x8F,0x00,0x00], 0, "QDF", "QDF Quicken data", ["qdf"], ""),
FileFormat([0xAC,0xED], 0, "Java serialization data", "Java serialization data", ["*"], ""),
FileFormat([0xAC,0xED,0x00,0x05,0x73,0x72,0x00,0x12], 0, "PDB", "BGBlitz position database file", ["pdb"], ""),
FileFormat([0xB0,0x4D,0x46,0x43], 0, "PWL", "Win95 password file", ["pwl"], ""),
FileFormat([0xB1,0x68,0xDE,0x3A], 0, "DCX", "PCX bitmap", ["dcx"], "Pictures"),
FileFormat([0xB4,0x6E,0x68,0x44], 0, "TIB", "Acronis True Image", ["tib"], ""),
FileFormat([0xB5,0xA2,0xB0,0xB3,0xB3,0xB0,0xA5,0xB5], 0, "CAL", "Windows calendar", ["cal"], ""),
FileFormat([0xBE,0x00,0x00,0x00,0xAB], 0, "WRI", "MS Write file_3", ["wri"], ""),
FileFormat([0xC3,0xAB,0xCD,0xAB], 0, "ACS", "MS Agent Character file", ["acs"], ""),
FileFormat([0xC5,0xD0,0xD3,0xC6], 0, "EPS", "Adobe encapsulated PostScript", ["eps"], ""),
FileFormat([0xC8,0x00,0x79,0x00], 0, "LBK", "Jeppesen FliteLog file", ["lbk"], ""),
FileFormat([0xCA,0xFE,0xBA,0xBE], 0, "Java bytecode", "Java bytecode", ["class"], ""),
FileFormat([0xCD,0x20,0xAA,0xAA,0x02,0x00,0x00,0x00], 0, "NAV quarantined virus file", "Norton Antivirus quarantined virus file", ["*"], ""),
FileFormat([0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1,0x00], 0, "Perfect Office document", "Perfect Office document", ["doc"], "Documents"),
FileFormat([0xCF,0xAD,0x12,0xFE], 0, "DBX", "Outlook Express e-mail folder", ["dbx"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "DOC", "MS Office text document", ["doc"], "Documents"),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "DOT", "MS Office document", ["dot"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "PPT", "MS Office presentation", ["ppt"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "PPS", "MS Office document", ["pps"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "PUB", "MS Publisher file", ["pub"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "WIZ", "Microsoft Office document", ["wiz"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "MSI", "Microsoft Installer package", ["msi"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "MSC", "Microsoft Common Console Document", ["msc"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "XLA", "Microsoft Office document", ["xla"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "VSD", "Visio file", ["vsd"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "DB", "MSWorks database file", ["db"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "OPT", "Developer Studio File Options file", ["opt"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "SOU", "Visual Studio Solution User Options file", ["sou"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "APR", "Lotus|IBM Approach 97 file", ["apr"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "MTW", "Minitab data file", ["mtw"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "XLA", "Microsoft Office document", ["xla"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "SOU", "Visual Studio Solution User Options file", ["sou"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "APR", "Lotus|IBM Approach 97 file", ["apr"], ""),
FileFormat([0xD0,0xCF,0x11,0xE0,0xA1,0xB1,0x1A,0xE1], 0, "MTW", "Minitab data file", ["mtw"], ""),
FileFormat([0xD2,0x0A,0x00,0x00], 0, "FTR", "WinPharoah filter file", ["ftr"], ""),
FileFormat([0xD4,0x2A], 0, "AOL history|typed URL files", "AOL history|typed URL files", ["arl", "aut"], ""),
FileFormat([0xD4,0xC3,0xB2,0xA1], 0, "WinDump (winpcap) capture file", "WinDump (winpcap) capture file", ["*"], ""),
FileFormat([0xD7,0xCD,0xC6,0x9A], 0, "WMF", "Windows graphics metafile", ["wmf"], ""),
FileFormat([0xDB,0xA5,0x2D,0x00], 0, "Word 2.0 file", "Word 2.0 file", ["doc"], ""),
FileFormat([0xDC,0xDC], 0, "CPL", "Corel color palette", ["cpl"], ""),
FileFormat([0xDC,0xFE], 0, "EFX", "eFax file", ["efx"], ""),
FileFormat([0xE3,0x10,0x00,0x01,0x00,0x00,0x00,0x00], 0, "Amiga icon", "Amiga icon", ["info"], ""),
FileFormat([0xE3,0x82,0x85,0x96], 0, "PWL", "Win98 password file", ["pwl"], ""),
FileFormat([0xE4,0x52,0x5C,0x7B,0x8C,0xD8,0xA7,0x4D], 0, "ONE", "MS OneNote note", ["one"], ""),
FileFormat([0xE8], 0, "COM", "Windows executable", ["com"], ""),
FileFormat([0xE8], 0, "SYS", "Windows executable", ["sys"], ""),
FileFormat([0xE9], 0, "COM", "Windows executable", ["com"], ""),
FileFormat([0xE9], 0, "SYS", "Windows executable", ["sys"], ""),
FileFormat([0xEB], 0, "COM", "Windows executable", ["com"], ""),
FileFormat([0xEB], 0, "SYS", "Windows executable", ["sys"], ""),
FileFormat([0xEB,0x3C,0x90,0x2A], 0, "GEM Raster file", "GEM Raster file", ["img"], ""),
FileFormat([0xED,0xAB,0xEE,0xDB], 0, "RPM", "RedHat Package format", ["rpm"], ""),
FileFormat([0xFD,0x37,0x1A,0x58,0x5A,0x00,0x00], 0, "XZ", "XZ archive", ["xz"], "Archives"),
FileFormat([0xFE,0xEF], 0, "Symantex Ghost image file", "Symantex Ghost image file", ["ghs", "gho"], ""),
FileFormat([0xFF], 0, "SYS", "Windows executable", ["sys"], ""),
FileFormat([0xFF,0x00,0x02,0x00,0x04,0x04,0x05,0x54], 0, "WKS", "Works for Windows spreadsheet", ["wks"], ""),
FileFormat([0xFF,0x46,0x4F,0x4E,0x54], 0, "CPI", "Windows international code page", ["cpi"], ""),
FileFormat([0xFF,0x57,0x50,0x43], 0, "WordPerfect format", "WordPerfect text and graphics", ["wpp", "wpg", "wpd", "wp6", "wp5", "wp"], ""),
FileFormat([0xFF,0xD8,0xFF], 0, "JPEG", "JPEG image", ["jpe", "jfif", "jpeg", "jpg"], "Pictures"),
FileFormat([0xFF,0xFB], 0, "MP3", "MP3 audio file", ["mp3"], "Audio"),
FileFormat([0xFF,0xFE], 0, "REG", "Windows Registry file", ["reg", "*"], ""),
FileFormat([0xFF,0xFE,0x23,0x00,0x6C,0x00,0x69,0x00], 0, "MOF", "MSinfo file", ["mof"], ""),
FileFormat([0xFF,0xFF,0xFF,0xFF], 0, "DOS system driver", "DOS system driver", ["sys"], ""),
FileFormat([0x47,0x40], 0, "TS", "TS mediacontainer", ["ts"], "Video"),
FileFormat([0x3C,0x3F,0x78,0x6D,0x6C,0x20,0x76,0x65,0x72,0x73,0x69,0x6F,0x6E,0x3D], 0, "FB2", "FictionBook document", ["fb2"], "Documents"),
FileFormat([0x50,0x4B,0x03,0x04], 0, "EPUB", "Electronic Publication format", ["epub"], "Documents"),
FileFormat(null, 0, "HTML", "HyperText Markup Language file", ["html"], "Text"),
FileFormat([0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x4F,0x4F,0x4B,0x4D,0x4F,0x42,0x49], 48, "MOBI", "Mobipocket e-book format", ["mobi"], "Documents"),
FileFormat([0x28,0xB5,0x2F,0xFD], 0, "ZST", "Zstandard compressed file", ["zst"], "Archives"),
];
